from setuptools import setup

setup(name='NanSwap',
      version='0.1',
      description='The NanSwap Python API',
      url='https://github.com/MyEcoria/NanSwap_module',
      author='MyEcoria',
      author_email='contact@myecoria.com',
      license='MIT',
      packages=['NanSwap'])
